server_client_20141211_231026

### config1 : test_load_balance

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 3.46306204796 sec | 5.74788498878 sec

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0
latency | 1.30 | 0.44 | 0.26 | 0.34 | 0.41 | 0.62 | 0.93 | 1.23 | 0.28

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 40.17 | 29.77 | 24.37 | 24.77 | 32.47 | 37.09 | 38.63 | 39.86 | 7.36
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.3425
server1-perf | latency | mean lt 0.33 | 0.443333333333
server1-perf | qps | mean lt 7.0 | 4.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 24.766
client1-perf | latency | mean lt 35.0 | 29.768
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None